changeset 757:4c59838006e0 draft

Yet another new tests added into BitBltUsingBgColor.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Fri, 04 Sep 2015 12:11:06 +0200
parents 3ea01f17c392
children 989aac642f22
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 34 insertions(+), 29 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Thu Sep 03 10:23:24 2015 +0200
+++ b/ChangeLog	Fri Sep 04 12:11:06 2015 +0200
@@ -1,3 +1,8 @@
+2015-09-04  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Yet another new tests added into BitBltUsingBgColor.
+
 2015-09-03  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Sep 03 10:23:24 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Fri Sep 04 12:11:06 2015 +0200
@@ -10816,7 +10816,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
      * Background color is set to Color.black.
      *
      * @param image
@@ -10825,13 +10825,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
+    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -10840,13 +10840,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
+    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -10855,13 +10855,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
+    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -10870,13 +10870,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
+    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -10816,7 +10816,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      * Background color is set to Color.black.
      *